/***************************************************************************
 * Copyright (c) 2006 Digi International Inc., All Rights Reserved
 *
 * This software contains proprietary and confidential information of Digi
 * International Inc.  By accepting transfer of this copy, Recipient agrees
 * to retain this software in confidence, to prevent disclosure to others,
 * and to make no use of this software other than that for which it was
 * delivered.  This is an unpublished copyrighted work of Digi International
 * Inc.  Except as permitted by federal law, 17 USC 117, copying is strictly
 * prohibited.
 *
 * Restricted Rights Legend
 *
 * Use, duplication, or disclosure by the Government is subject to
 * restrictions set forth in sub-paragraph (c)(1)(ii) of The Rights in
 * Technical Data and Computer Software clause at DFARS 252.227-7031 or
 * subparagraphs (c)(1) and (2) of the Commercial Computer Software -
 * Restricted Rights at 48 CFR 52.227-19, as applicable.
 *
 * Digi International Inc. 11001 Bren Road East, Minnetonka, MN 55343
 * 
 ***************************************************************************
 *
 * $Id: partition2reg.c,v 1.1 2008-01-08 14:02:54 mengel Exp $
 *
 * @Descr: Saves all partition inforamtion in registry.
 *
 * @History:
 *	01/09/07:	Initial version.
 *	
 *
 ***************************************************************************/

#ifndef __COMMON_DIGI_H
#define __COMMON_DIGI_H

//------------------------------------------------------------------------------
// Module type definition.
//------------------------------------------------------------------------------
#define CC9M2443	0x67F
#define CCWi9M2443	0x862
#define CC9C		0x344
#define CCWi9C		0x456
#define CC9P9360	0x4F0
#define CC9P9750	0xFFF
#define CCWiMX51	0x9D7
#define CCMX51		0x9D5
#define CCWiMX53	0xd15	//TODO53: This is what it is reporting now
#define CCMX53		0xd13	//TODO53

//------------------------------------------------------------------------------
// GPIO device driver structure.
//------------------------------------------------------------------------------

// Main structure of port information
typedef struct _GPIOInformation
{
	void				*pGPIORegisters;	// used for any SOC GPIO special register
	void				*pGPIOConf;			// GPIOMessage structure 
	CRITICAL_SECTION	g_IOCtlCritGPIO;	// global critical section
}GPIOInformation, *PGPIOInformation;

//------------------------------------------------------------------------------
// I2C device driver structure.
//------------------------------------------------------------------------------
/* common device context */
typedef struct _I2C_CONTEXT {

	// I2C Registers
    void	*pI2CReg;
    // GPIO Ports
    void    *pIOPReg;
    // Clock / Power
    void	*pCLKPWRReg;
	void	*pI2CInstance;		// platfrom specific information 
    CRITICAL_SECTION RegCS;		// Register CS
    DWORD       SlaveAddress;   // Our I2C Slave Address
	DWORD       OpenCount;
} I2C_CONTEXT, *PI2C_CONTEXT;

//
// I/O DESCRIPTOR for Read/Write
//
typedef struct _I2C_IO_DESC {
    DWORD   SlaveAddr;      // Target Slave Address
	ULONG	WordAddr;       // starting word address
	ULONG   WordAddrLen;    // slave word address Lenght
    PUCHAR  Data;           // pBuffer
    DWORD   Count;          // nBytes to read/write
} I2C_IO_DESC, *PI2C_IO_DESC;

//------------------------------------------------------------------------------
// ADC device driver structure.
//------------------------------------------------------------------------------
typedef struct _ADCInformation
{
	CRITICAL_SECTION	CritAdcDrv;
	DWORD				dwChannelsInUse;				// Mask of chaneds in use and configured

} ADCInformation, *PADCInformation;

typedef struct _ADCChannel
{
	struct _ADCInformation*	pPortObj;
	CRITICAL_SECTION		CritAdcChannel;
	BOOL					blPortConfigured;		
	DWORD					dwChannel;
	DWORD					dwAvgSamples;
	DWORD					dwSkipSamples;
	enum ADC_MODE			Mode;
	DWORD					dwSamplePeriodMS;
	HANDLE					TimerThread;
	INT						nTimer;
	HANDLE					hTimerEvent;
	BOOL					timerIsSet;
	BOOL					cancelTimer;
	HANDLE					hSampleSem;			// Semaphore to syncr between timer and Read when running in ADC_MODE_PERIODIC
	USHORT					usValue;
} ADCChannel, *PADCChannel;

DWORD pddGetNumChannels(void);
int pddAdcMapRegisterAddresses(PADCInformation pPortObj);
int pddAdcUnmapRegisterAddresses(PADCInformation pPortObj);
BOOL pddInitialize(PADCInformation pPortObj);
BOOL pddSetMode(PADCChannel pChannel);
void pddPowerUp(PADCInformation pPortObj);
void pddPowerDown(PADCInformation pPortObj);
BOOL pddDeInitialize(PADCInformation pPortObj);
USHORT pddReadValue(PADCChannel pChannel);

#define DOSKEY_BUFFER_SIZE	1024	//Max= 65536/2

//------------------------------------------------------------------------------
// DbgConsole device driver structure.
//------------------------------------------------------------------------------
typedef struct _DbgConsoleInformation
{
  	unsigned int		unPortOpen;			//set for opened port
	unsigned char		ucDbgUart;			//Uart used for debug console
	CRITICAL_SECTION	CS;					//Critical section
	unsigned char		DoskeyBuffer[DOSKEY_BUFFER_SIZE];
	unsigned short		DoskeyPointer[DOSKEY_BUFFER_SIZE];	//In case user saves 1 character each time
	unsigned int		DoskeyTail;
	unsigned int		DoskeyHead;
} DbgConsoleInformation, *PDbgConsoleInformation;

typedef struct _DbgConsoleInstance
{
	PDbgConsoleInformation	pDbgConsoleObj;
} DbgConsoleInstance, *PDbgConsoleInstance;

#define DBG_CONSOLE_READ_NODATA (-1)

#define pDoskeyBuffer	pDbgConsoleInstance->pDbgConsoleObj->DoskeyBuffer
#define pDoskeyPointer	pDbgConsoleInstance->pDbgConsoleObj->DoskeyPointer
#define DoskeyHead		pDbgConsoleInstance->pDbgConsoleObj->DoskeyHead
#define DoskeyTail		pDbgConsoleInstance->pDbgConsoleObj->DoskeyTail

BOOL pddDbgConsoleMapRegisterAddresses(PDbgConsoleInformation pDbgConsoleObj);
BOOL pddDbgConsoleUnmapRegisterAddresses(PDbgConsoleInformation pDbgConsoleObj);
int pddDbgConsoleReadDebugByte(void);

//------------------------------------------------------------------------------
// XXXX device driver structure.
//------------------------------------------------------------------------------


//------------------------------------------------------------------------------

#endif // __COMMON_DIGI_H
