/***************************************************************************
 * Copyright (c) 2009 Digi International Inc., All Rights Reserved
 *
 * This software contains proprietary and confidential information of Digi
 * International Inc.  By accepting transfer of this copy, Recipient agrees
 * to retain this software in confidence, to prevent disclosure to others,
 * and to make no use of this software other than that for which it was
 * delivered.  This is an unpublished copyrighted work of Digi International
 * Inc.  Except as permitted by federal law, 17 USC 117, copying is strictly
 * prohibited.
 *
 * Restricted Rights Legend
 *
 * Use, duplication, or disclosure by the Government is subject to
 * restrictions set forth in sub-paragraph (c)(1)(ii) of The Rights in
 * Technical Data and Computer Software clause at DFARS 252.227-7031 or
 * subparagraphs (c)(1) and (2) of the Commercial Computer Software -
 * Restricted Rights at 48 CFR 52.227-19, as applicable.
 *
 * Digi International Inc. 11001 Bren Road East, Minnetonka, MN 55343
 * 
 ***************************************************************************
 *
 * $Id: common_drv_ioctl.h,v 1.0 2009-05-18 11:41:56 aramos Exp $
 *
 * @Descr: Common driver IOCTL definition header file for some drivers
 *
 * @History:
 *	08/06/09:	Initial version.
 *	
 *
 ***************************************************************************/
#ifndef _COMMON_DRV_IOCTL_H_
#define _COMMON_DRV_IOCTL_H_

#if __cplusplus
extern "C" {
#endif

//------------------------------------------------------------------------------
// GPIO driver IOCTLs
//------------------------------------------------------------------------------
// OEM defined:
#define FILE_DEVICE_GPIO_PORT 	32770	//OEM

#define IOCTL_GPIO_WRITE		CTL_CODE(FILE_DEVICE_GPIO_PORT,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_GPIO_READ			CTL_CODE(FILE_DEVICE_GPIO_PORT,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_GPIO_CONFIG		CTL_CODE(FILE_DEVICE_GPIO_PORT,0x802,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_GPIO_WAIT_FOR_IRQ	CTL_CODE(FILE_DEVICE_GPIO_PORT,0x803,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_GPIO_RELEASE		CTL_CODE(FILE_DEVICE_GPIO_PORT,0x804,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_GPIO_BLOCK		CTL_CODE(FILE_DEVICE_GPIO_PORT,0x805,METHOD_BUFFERED,FILE_ANY_ACCESS)

// API interrupt Flags
#define FLAG_INTR_LEVEL 0x00000001		// Interrupt is level sensitive, if not: Edge detect
#define FLAG_INTR_INVER 0x00000002		// Interrupt is Active low (or low edge), if not: Active high (or high edge)
#define FLAG_PULL_UP	0x00000004		// Set Pin Pull-Up
#define FLAG_PULL_DOWN	0x00000008		// Set Pin Pull-Down

typedef enum 
{
	GPIO_UNCONFIG,
	GPIO_INPUT,
	GPIO_OUTPUT,
	GPIO_IRQ,
	GPIO_OTHER,
	GPIO_USED,
	GPIO_NOT_EXIST,
} GPIOMODE;

//------------------------------------------------------------------------------
// MEMORY driver IOCTLs
//------------------------------------------------------------------------------
// OEM defined:
#define FILE_DEVICE_MEM_DRV_PORT 	32773	//OEM

#define IOCTL_MEM_DRV_WRITE		CTL_CODE(FILE_DEVICE_MEM_DRV_PORT,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_MEM_DRV_READ		CTL_CODE(FILE_DEVICE_MEM_DRV_PORT,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)

struct io_struct
{
	unsigned int addr;
	unsigned int length;		// now in bytes
	unsigned char ucAccessSize; // 8,16 or 32 bit access size
};

//------------------------------------------------------------------------------
// NAND block device driver RESERVED IOCTLs
//------------------------------------------------------------------------------
//#include <diskio.h>

// OEM defined:

#define IOCTL_FMD_CHECKBAD_RESERVED      IOCTL_DISK_USER(30)
#define IOCTL_FMD_ERASE_RESERVED         IOCTL_DISK_USER(31)

#define IOCTL_FMD_READ_SPARE_RESERVED		IOCTL_DISK_USER(32)
#define IOCTL_FMD_WRITE_SPARE_RESERVED		IOCTL_DISK_USER(33)
#define IOCTL_FMD_MARKBADBLOCK_RESERVED		IOCTL_DISK_USER(34)
#define IOCTL_FMD_UNMARKBADBLOCK_RESERVED	IOCTL_DISK_USER(35)

#define IOCTL_FMD_DIGI_READ_RESERVED	IOCTL_DISK_USER(36)
#define IOCTL_FMD_DIGI_WRITE_RESERVED	IOCTL_DISK_USER(37)

typedef struct _ReservedSpareReq
{
    DWORD dwStart;
    DWORD dwLen;
    LPBYTE pBuffer;
	LPBYTE pSpareBuffer;
}ReservedSpareReq, *PReservedSpareReq;

//------------------------------------------------------------------------------
// External RTC driver
//------------------------------------------------------------------------------
#define FILE_DEVICE_EXTRTC			32775	//OEM

// Read & Write functions can be used to read/write any ExtRTC register.
#define IOCTL_EXTRTC_WRITE			CTL_CODE(FILE_DEVICE_EXTRTC,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_EXTRTC_READ			CTL_CODE(FILE_DEVICE_EXTRTC,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_EXTRTC_SET_ALARM		CTL_CODE(FILE_DEVICE_EXTRTC,0x802,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_EXTRTC_GET_ALARM		CTL_CODE(FILE_DEVICE_EXTRTC,0x803,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_EXTRTC_WAIT_ALARM		CTL_CODE(FILE_DEVICE_EXTRTC,0x804,METHOD_BUFFERED,FILE_ANY_ACCESS)

#define EXTRTC_ALARM_FLAG_SIGNALED		0x00000001
#define EXTRTC_ALARM_FLAG_TIMEOUT		0x00000002
#define EXTRTC_ALARM_FLAG_CANCELED		0x00000004
#define EXTRTC_ALARM_FLAG_ENABLED		0x00000008
#define EXTRTC_ALARM_FLAG_DISABLED		0x00000010

//------------------------------------------------------------------------------
// PCIe driver IOCTLs
//------------------------------------------------------------------------------
// OEM defined:
#define FILE_DEVICE_PCIe_DRV_PORT 	32776	//OEM

#define IOCTL_PCIe_DRV_ENABLE	CTL_CODE(FILE_DEVICE_PCIe_DRV_PORT,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PCIe_DRV_DISABLE	CTL_CODE(FILE_DEVICE_PCIe_DRV_PORT,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PCIe_DRV_RESET	CTL_CODE(FILE_DEVICE_PCIe_DRV_PORT,0x802,METHOD_BUFFERED,FILE_ANY_ACCESS)

//------------------------------------------------------------------------------
// Power driver IOCTLs
//------------------------------------------------------------------------------
// OEM defined:
#define FILE_DEVICE_PWR_DRV_PORT 	32777	//OEM

#define IOCTL_PWR_SET_WAKE		 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_QUERY_WAKE	 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_QUERY_WAKE_ALL CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x802,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_AWAKE_SYSINTR	 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x803,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_REQUEST_NOTIFICATION	 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x804,METHOD_BUFFERED,FILE_ANY_ACCESS)

#define IOCTL_PWR_SUSPEND		 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x810,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_RESET			 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x811,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_RESET_WARM	 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x812,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_HALT			 CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x813,METHOD_BUFFERED,FILE_ANY_ACCESS)

#define IOCTL_PWR_SET_SUSPEND_CFG	CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x820,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_PWR_QUERY_SUSPEND_CFG	CTL_CODE(FILE_DEVICE_PWR_DRV_PORT,0x821,METHOD_BUFFERED,FILE_ANY_ACCESS)


#define MAX_WAKEUPINTERFACE_KEYNAME		20
#define MAX_WAKEUP_INTERFACES			25

typedef struct _WakeInterface
{
	char szInterface[MAX_WAKEUPINTERFACE_KEYNAME];
    DWORD dwSysIntr;
    DWORD dwValue;
}WakeInterface, *PWakeInterface;

#define MAX_SUSPENDCFGCONFIGURATION_KEYNAME		20

typedef struct _SuspendCfg
{
	char szConfiguration[MAX_SUSPENDCFGCONFIGURATION_KEYNAME];
    DWORD dwValue;
}SuspendCfg, *PSuspendCfg;

typedef struct{
  HANDLE hMsgQueue;
  DWORD dwNotificationTypes;
}PWRCTRL_REQUEST_NOTIFICATION, *PPWRCTRL_REQUEST_NOTIFICATION;

typedef struct{
	DWORD	dwNotificationType;
    DWORD	dwSysIntr;
    DWORD	dwValue;
}PWRCTRL_DEVICE_NOTIFICATION, *PPWRCTRL_DEVICE_NOTIFICATION;

#define PWRCTRL_NOTIFICATION_WAKE_STATE_CHANGE		0x00000001
#define PWRCTRL_NOTIFICATION_SUSPEND_CFG_CHANGE		0x00000002

//------------------------------------------------------------------------------
// ADC driver
//------------------------------------------------------------------------------

#define FILE_DEVICE_ADC_PORT 	32774	//OEM

#define IOCTL_ADC_SELECT_CHANNEL		CTL_CODE(FILE_DEVICE_ADC_PORT,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_ADC_SET_NUM_AVG			CTL_CODE(FILE_DEVICE_ADC_PORT,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_ADC_SET_NUM_SKIP			CTL_CODE(FILE_DEVICE_ADC_PORT,0x802,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_ADC_SET_SAMPLE_PERIOD_MS	CTL_CODE(FILE_DEVICE_ADC_PORT,0x803,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_ADC_SET_MODE				CTL_CODE(FILE_DEVICE_ADC_PORT,0x804,METHOD_BUFFERED,FILE_ANY_ACCESS)

#define ADC_MAX_SAMPLES_SKIP			10
#define	ADC_MAX_SAMPLES_AVG				10
#define	ADC_MIN_SAMPLE_PERIOD_MS		5

#define	ADC_DEFAULT_SAMPLES_AVG			3
#define	ADC_DEFAULT_SAMPLE_SKIP			1
#define	ADC_DEFAULT_SAMPLE_PERIOD_MS	200

typedef enum 
{
	ADC_MODE_ONE_SHOOT,
	ADC_MODE_PERIODIC
} ADC_MODE;

//------------------------------------------------------------------------------
// Dual Touch driver IOCTLs
//------------------------------------------------------------------------------

#define FILE_DEVICE_TOUCH_PORT 	32775	//OEM

#define IOCTL_TOUCH_GETDEVICECAPS				CTL_CODE(FILE_DEVICE_TOUCH_PORT,0x800,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_TOUCH_READCALPOINT				CTL_CODE(FILE_DEVICE_TOUCH_PORT,0x801,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_TOUCH_SETCALIBRATION				CTL_CODE(FILE_DEVICE_TOUCH_PORT,0x802,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_TOUCH_SETCALIBRATION_DUALTOUCH	CTL_CODE(FILE_DEVICE_TOUCH_PORT,0x803,METHOD_BUFFERED,FILE_ANY_ACCESS)
#define IOCTL_TOUCH_GETBSPARGS					CTL_CODE(FILE_DEVICE_TOUCH_PORT,0x804,METHOD_BUFFERED,FILE_ANY_ACCESS)

#if __cplusplus
}
#endif

#endif //_COMMON_DRV_IOCTL_H_
